pub struct BulletList {
pub bullet: Option<String>,
}Fields
bullet: Option<String>Trait Implementations
Sourceimpl Clone for BulletList
impl Clone for BulletList
Sourcefn clone(&self) -> BulletList
fn clone(&self) -> BulletList
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BulletList
impl Debug for BulletList
Sourceimpl Default for BulletList
impl Default for BulletList
Sourcefn default() -> BulletList
fn default() -> BulletList
Returns the “default value” for a type. Read more
Sourceimpl ExtraAttributes<BulletList> for BulletList
impl ExtraAttributes<BulletList> for BulletList
fn with_extra(extra: BulletList) -> BulletList
fn extra(&self) -> &BulletList
fn extra_mut(&mut self) -> &mut BulletList
Sourceimpl JsonSchema for BulletList
impl JsonSchema for BulletList
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BulletList
impl PartialEq for BulletList
Sourceimpl Serialize for BulletList
impl Serialize for BulletList
impl StructuralPartialEq for BulletList