pub struct CitationReference {
pub refid: Option<ID>,
pub refname: Vec<NameToken>,
}Fields
refid: Option<ID>refname: Vec<NameToken>Trait Implementations
Sourceimpl Clone for CitationReference
impl Clone for CitationReference
Sourcefn clone(&self) -> CitationReference
fn clone(&self) -> CitationReference
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CitationReference
impl Debug for CitationReference
Sourceimpl Default for CitationReference
impl Default for CitationReference
Sourcefn default() -> CitationReference
fn default() -> CitationReference
Returns the “default value” for a type. Read more
Sourceimpl ExtraAttributes<CitationReference> for CitationReference
impl ExtraAttributes<CitationReference> for CitationReference
fn with_extra(extra: CitationReference) -> CitationReference
fn extra(&self) -> &CitationReference
fn extra_mut(&mut self) -> &mut CitationReference
Sourceimpl JsonSchema for CitationReference
impl JsonSchema for CitationReference
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CitationReference
impl PartialEq for CitationReference
Sourceimpl Serialize for CitationReference
impl Serialize for CitationReference
impl StructuralPartialEq for CitationReference