pub struct Comment {
pub space: FixedSpace,
}Fields
space: FixedSpaceTrait Implementations
Sourceimpl ExtraAttributes<Comment> for Comment
impl ExtraAttributes<Comment> for Comment
Sourceimpl JsonSchema for Comment
impl JsonSchema for Comment
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for Comment