pub struct DoctestBlock {
pub space: FixedSpace,
}Fields
space: FixedSpaceTrait Implementations
Sourceimpl Clone for DoctestBlock
impl Clone for DoctestBlock
Sourcefn clone(&self) -> DoctestBlock
fn clone(&self) -> DoctestBlock
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DoctestBlock
impl Debug for DoctestBlock
Sourceimpl Default for DoctestBlock
impl Default for DoctestBlock
Sourcefn default() -> DoctestBlock
fn default() -> DoctestBlock
Returns the “default value” for a type. Read more
Sourceimpl ExtraAttributes<DoctestBlock> for DoctestBlock
impl ExtraAttributes<DoctestBlock> for DoctestBlock
fn with_extra(extra: DoctestBlock) -> DoctestBlock
fn extra(&self) -> &DoctestBlock
fn extra_mut(&mut self) -> &mut DoctestBlock
Sourceimpl JsonSchema for DoctestBlock
impl JsonSchema for DoctestBlock
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DoctestBlock
impl PartialEq for DoctestBlock
Sourceimpl Serialize for DoctestBlock
impl Serialize for DoctestBlock
impl StructuralPartialEq for DoctestBlock