pub struct FootnoteReference {
pub refid: Option<ID>,
pub refname: Vec<NameToken>,
pub auto: Option<FootnoteType>,
}Fields
refid: Option<ID>refname: Vec<NameToken>auto: Option<FootnoteType>Trait Implementations
Sourceimpl Clone for FootnoteReference
impl Clone for FootnoteReference
Sourcefn clone(&self) -> FootnoteReference
fn clone(&self) -> FootnoteReference
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FootnoteReference
impl Debug for FootnoteReference
Sourceimpl Default for FootnoteReference
impl Default for FootnoteReference
Sourcefn default() -> FootnoteReference
fn default() -> FootnoteReference
Returns the “default value” for a type. Read more
Sourceimpl ExtraAttributes<FootnoteReference> for FootnoteReference
impl ExtraAttributes<FootnoteReference> for FootnoteReference
fn with_extra(extra: FootnoteReference) -> FootnoteReference
fn extra(&self) -> &FootnoteReference
fn extra_mut(&mut self) -> &mut FootnoteReference
Sourceimpl JsonSchema for FootnoteReference
impl JsonSchema for FootnoteReference
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for FootnoteReference
impl PartialEq for FootnoteReference
Sourceimpl Serialize for FootnoteReference
impl Serialize for FootnoteReference
impl StructuralPartialEq for FootnoteReference