pub struct LiteralBlock {
pub space: FixedSpace,
}Fields
space: FixedSpaceTrait Implementations
Sourceimpl Clone for LiteralBlock
impl Clone for LiteralBlock
Sourcefn clone(&self) -> LiteralBlock
fn clone(&self) -> LiteralBlock
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LiteralBlock
impl Debug for LiteralBlock
Sourceimpl Default for LiteralBlock
impl Default for LiteralBlock
Sourcefn default() -> LiteralBlock
fn default() -> LiteralBlock
Returns the “default value” for a type. Read more
Sourceimpl ExtraAttributes<LiteralBlock> for LiteralBlock
impl ExtraAttributes<LiteralBlock> for LiteralBlock
fn with_extra(extra: LiteralBlock) -> LiteralBlock
fn extra(&self) -> &LiteralBlock
fn extra_mut(&mut self) -> &mut LiteralBlock
Sourceimpl JsonSchema for LiteralBlock
impl JsonSchema for LiteralBlock
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for LiteralBlock
impl PartialEq for LiteralBlock
Sourceimpl Serialize for LiteralBlock
impl Serialize for LiteralBlock
impl StructuralPartialEq for LiteralBlock