pub struct Problematic {
pub refid: Option<ID>,
}Fields
refid: Option<ID>Trait Implementations
Sourceimpl Clone for Problematic
impl Clone for Problematic
Sourcefn clone(&self) -> Problematic
fn clone(&self) -> Problematic
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Problematic
impl Debug for Problematic
Sourceimpl Default for Problematic
impl Default for Problematic
Sourcefn default() -> Problematic
fn default() -> Problematic
Returns the “default value” for a type. Read more
Sourceimpl ExtraAttributes<Problematic> for Problematic
impl ExtraAttributes<Problematic> for Problematic
fn with_extra(extra: Problematic) -> Problematic
fn extra(&self) -> &Problematic
fn extra_mut(&mut self) -> &mut Problematic
Sourceimpl JsonSchema for Problematic
impl JsonSchema for Problematic
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for Problematic
impl PartialEq for Problematic
Sourceimpl Serialize for Problematic
impl Serialize for Problematic
impl StructuralPartialEq for Problematic