pub struct SubstitutionReference {
pub refname: Vec<NameToken>,
}Fields
refname: Vec<NameToken>Trait Implementations
Sourceimpl Clone for SubstitutionReference
impl Clone for SubstitutionReference
Sourcefn clone(&self) -> SubstitutionReference
fn clone(&self) -> SubstitutionReference
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SubstitutionReference
impl Debug for SubstitutionReference
Sourceimpl Default for SubstitutionReference
impl Default for SubstitutionReference
Sourcefn default() -> SubstitutionReference
fn default() -> SubstitutionReference
Returns the “default value” for a type. Read more
Sourceimpl ExtraAttributes<SubstitutionReference> for SubstitutionReference
impl ExtraAttributes<SubstitutionReference> for SubstitutionReference
fn with_extra(extra: SubstitutionReference) -> SubstitutionReference
fn extra(&self) -> &SubstitutionReference
fn extra_mut(&mut self) -> &mut SubstitutionReference
Sourceimpl JsonSchema for SubstitutionReference
impl JsonSchema for SubstitutionReference
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SubstitutionReference
impl PartialEq for SubstitutionReference
Sourceimpl Serialize for SubstitutionReference
impl Serialize for SubstitutionReference
impl StructuralPartialEq for SubstitutionReference