pub struct SystemMessage {
pub backrefs: Vec<ID>,
pub level: Option<usize>,
pub line: Option<usize>,
pub type_: Option<NameToken>,
}Fields
backrefs: Vec<ID>level: Option<usize>line: Option<usize>type_: Option<NameToken>Trait Implementations
Sourceimpl Clone for SystemMessage
impl Clone for SystemMessage
Sourcefn clone(&self) -> SystemMessage
fn clone(&self) -> SystemMessage
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SystemMessage
impl Debug for SystemMessage
Sourceimpl Default for SystemMessage
impl Default for SystemMessage
Sourcefn default() -> SystemMessage
fn default() -> SystemMessage
Returns the “default value” for a type. Read more
Sourceimpl ExtraAttributes<SystemMessage> for SystemMessage
impl ExtraAttributes<SystemMessage> for SystemMessage
fn with_extra(extra: SystemMessage) -> SystemMessage
fn extra(&self) -> &SystemMessage
fn extra_mut(&mut self) -> &mut SystemMessage
Sourceimpl JsonSchema for SystemMessage
impl JsonSchema for SystemMessage
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SystemMessage
impl PartialEq for SystemMessage
Sourceimpl Serialize for SystemMessage
impl Serialize for SystemMessage
impl StructuralPartialEq for SystemMessage