pub struct Table {
pub frame: Option<TableBorder>,
pub colsep: Option<bool>,
pub rowsep: Option<bool>,
pub pgwide: Option<bool>,
}Fields
frame: Option<TableBorder>colsep: Option<bool>rowsep: Option<bool>pgwide: Option<bool>Trait Implementations
Sourceimpl ExtraAttributes<Table> for Table
impl ExtraAttributes<Table> for Table
Sourceimpl JsonSchema for Table
impl JsonSchema for Table
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for Table