pub struct TableColspec {
pub colnum: Option<usize>,
pub colname: Option<NameToken>,
pub colwidth: Option<String>,
pub colsep: Option<bool>,
pub rowsep: Option<bool>,
pub align: Option<TableAlignH>,
pub char: Option<char>,
pub charoff: Option<usize>,
pub stub: Option<bool>,
}Fields
colnum: Option<usize>colname: Option<NameToken>colwidth: Option<String>colsep: Option<bool>rowsep: Option<bool>align: Option<TableAlignH>char: Option<char>charoff: Option<usize>stub: Option<bool>Trait Implementations
Sourceimpl Clone for TableColspec
impl Clone for TableColspec
Sourcefn clone(&self) -> TableColspec
fn clone(&self) -> TableColspec
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TableColspec
impl Debug for TableColspec
Sourceimpl Default for TableColspec
impl Default for TableColspec
Sourcefn default() -> TableColspec
fn default() -> TableColspec
Returns the “default value” for a type. Read more
Sourceimpl ExtraAttributes<TableColspec> for TableColspec
impl ExtraAttributes<TableColspec> for TableColspec
fn with_extra(extra: TableColspec) -> TableColspec
fn extra(&self) -> &TableColspec
fn extra_mut(&mut self) -> &mut TableColspec
Sourceimpl JsonSchema for TableColspec
impl JsonSchema for TableColspec
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TableColspec
impl PartialEq for TableColspec
Sourceimpl Serialize for TableColspec
impl Serialize for TableColspec
impl StructuralPartialEq for TableColspec