pub struct TableRow {
pub rowsep: Option<bool>,
pub valign: Option<AlignV>,
}Fields
rowsep: Option<bool>valign: Option<AlignV>Trait Implementations
Sourceimpl ExtraAttributes<TableRow> for TableRow
impl ExtraAttributes<TableRow> for TableRow
Sourceimpl JsonSchema for TableRow
impl JsonSchema for TableRow
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for TableRow