pub struct Target {
pub refuri: Option<Url>,
pub refid: Option<ID>,
pub refname: Vec<NameToken>,
pub anonymous: bool,
}Fields
refuri: Option<Url>External reference to a URI/URL
refid: Option<ID>References to ids attributes in other elements
refname: Vec<NameToken>Internal reference to the names attribute of another element. May resolve to either an internal or external reference.
anonymous: boolTrait Implementations
Sourceimpl ExtraAttributes<Target> for Target
impl ExtraAttributes<Target> for Target
Sourceimpl JsonSchema for Target
impl JsonSchema for Target
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for Target