pub struct TargetInline {
pub refuri: Option<Url>,
pub refid: Option<ID>,
pub refname: Vec<NameToken>,
pub anonymous: bool,
}Fields
refuri: Option<Url>External reference to a URI/URL
refid: Option<ID>References to ids attributes in other elements
refname: Vec<NameToken>Internal reference to the names attribute of another element. May resolve to either an internal or external reference.
anonymous: boolTrait Implementations
Sourceimpl Clone for TargetInline
impl Clone for TargetInline
Sourcefn clone(&self) -> TargetInline
fn clone(&self) -> TargetInline
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TargetInline
impl Debug for TargetInline
Sourceimpl Default for TargetInline
impl Default for TargetInline
Sourcefn default() -> TargetInline
fn default() -> TargetInline
Returns the “default value” for a type. Read more
Sourceimpl ExtraAttributes<TargetInline> for TargetInline
impl ExtraAttributes<TargetInline> for TargetInline
fn with_extra(extra: TargetInline) -> TargetInline
fn extra(&self) -> &TargetInline
fn extra_mut(&mut self) -> &mut TargetInline
Sourceimpl JsonSchema for TargetInline
impl JsonSchema for TargetInline
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TargetInline
impl PartialEq for TargetInline
Sourceimpl Serialize for TargetInline
impl Serialize for TargetInline
impl StructuralPartialEq for TargetInline